import logging


class CustomFormatter(logging.Formatter):
    grey = '\x1b[38;21m'
    blue = '\x1b[38;5;39m'
    green = '\x1b[1;32m'
    yellow = '\x1b[38;5;226m'
    red = '\x1b[38;5;196m'
    bold_red = '\x1b[31;1m'
    reset = '\x1b[0m'


    def __init__(self, fmt):
        super().__init__()
        self.fmt = fmt
        self.FORMATS = {
            logging.DEBUG: self.grey + self.fmt + self.reset,
            logging.INFO: self.green + self.fmt + self.reset,
            logging.WARNING: self.yellow + self.fmt + self.reset,
            logging.ERROR: self.red + self.fmt + self.reset,
            logging.CRITICAL: self.bold_red + self.fmt + self.reset
        }


    def format(self, record):
        log_fmt = self.FORMATS.get(record.levelno)
        formatter = logging.Formatter(log_fmt)
        return formatter.format(record)



from distutils.core import setup

setup(
  name = 'py-colored-log',
  packages = ['py-colored-log'],
  version = '0.1',
  license='MIT',
  description = 'Lib to color application console logs',
  author = 'Felipe Gomes Machado',
  author_email = 'fgmachado0@gmail.com',
  url = 'https://github.com/fgmachado/py-colored-log',
  download_url = 'https://github.com/fgmachado/py-colored-log/archive/v_01.tar.gz',
  keywords = ['log', 'logger', 'logging', 'color'],
  install_requires = [
          'logging',
          'datetime',
    ],
  classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)


import logging
import datetime
import CustomFormatter


def init_logging(log_level=logging.INFO, format='%(asctime)s [%(levelname)s]: %(message)s'):
    logger = logging.getLogger(__name__)
    logger.setLevel(log_level)
    today = datetime.date.today()

    stdout_handler = logging.StreamHandler()
    stdout_handler.setLevel(logging.INFO)
    stdout_handler.setFormatter(CustomFormatter(format))

    file_handler = logging.FileHandler('{}.log'.format(today.strftime('%Y_%m_%d')))
    file_handler.setLevel(logging.DEBUG)
    file_handler.setFormatter(logging.Formatter(format))

    logger.addHandler(stdout_handler)
    logger.addHandler(file_handler)

    return logger
